Gallery
=======

Viewer (Mesher Results)
-----------------------

.. image:: ../gallery/viewer_1.png
.. image:: ../gallery/viewer_2.png
.. image:: ../gallery/viewer_3.png
.. image:: ../gallery/viewer_4.png

Plotter (Solver Results)
------------------------

.. image:: ../gallery/plotter_1.png
.. image:: ../gallery/plotter_2.png
.. image:: ../gallery/plotter_3.png
.. image:: ../gallery/plotter_4.png
.. image:: ../gallery/plotter_5.png
.. image:: ../gallery/plotter_6.png
.. image:: ../gallery/plotter_7.png
.. image:: ../gallery/plotter_8.png
.. image:: ../gallery/plotter_9.png
.. image:: ../gallery/plotter_10.png
